library rgb_color_picker;

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class RGBColorPickerDialog extends StatefulWidget {
  @override
  _RGBColorPickerDialogState createState() => _RGBColorPickerDialogState();

  final Color redSliderActiveColor;
  final Color blueSliderActiveColor;
  final Color greenSliderActiveColor;
  final Color redSliderThumbColor;
  final Color greenSliderThumbColor;
  final Color blueSliderThumbColor;
  final Color redSliderInActiveColor;
  final Color greenSliderInActiveColor;
  final Color blueSliderInActiveColor;
  final Color buttonTextColor;
  final SliderThemeData opacitySliderThemeData,
      redSliderThemeData,
      blueSliderThemeData,
      greenSliderThemeData;

  RGBColorPickerDialog({
    Key key,
    this.redSliderActiveColor = Colors.lightBlueAccent,
    this.blueSliderActiveColor = Colors.lightBlueAccent,
    this.greenSliderActiveColor = Colors.lightBlueAccent,
    this.redSliderThumbColor = Colors.lightBlueAccent,
    this.greenSliderThumbColor = Colors.lightBlueAccent,
    this.blueSliderThumbColor = Colors.lightBlueAccent,
    this.redSliderInActiveColor = Colors.grey,
    this.greenSliderInActiveColor = Colors.grey,
    this.blueSliderInActiveColor = Colors.grey,
    this.buttonTextColor = Colors.lightBlueAccent,
    this.blueSliderThemeData = const SliderThemeData(),
    this.greenSliderThemeData = const SliderThemeData(),
    this.opacitySliderThemeData = const SliderThemeData(),
    this.redSliderThemeData = const SliderThemeData(),
  }) : super(key: key);
}

class _RGBColorPickerDialogState extends State<RGBColorPickerDialog> {
  Color selectedColor;

  static double redSliderValue = 100;
  static double blueSliderValue = 100;
  static double greenSliderValue = 100;
  static double opacitySliderValue = 100;

  @override
  void initState() {
    super.initState();
    selectedColor = Color.fromRGBO(
        redSliderValue.round(),
        greenSliderValue.round(),
        blueSliderValue.round(),
        (opacitySliderValue / 100));
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () {
        Navigator.of(context).pop(selectedColor);
        return;
      },
      child: CupertinoAlertDialog(
        title: Material(
          color: Colors.white,
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Container(
                width: MediaQuery.of(context).size.width / 4,
                height: MediaQuery.of(context).size.width / 4,
                decoration: BoxDecoration(
                  color: selectedColor,
                  borderRadius: BorderRadius.circular(15),
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height / 20,
              ),
              Row(
                children: <Widget>[
                  CircleAvatar(
                    radius: MediaQuery.of(context).size.width / 30,
                    backgroundColor: Colors.redAccent.withOpacity(0.8),
                  ),
                  SliderTheme(
                    data: widget.redSliderThemeData,
                    child: Slider(
                      min: 0,
                      max: 256,
                      value: redSliderValue,
                      onChanged: (value) {
                        setState(() {
                          redSliderValue = value;
                        });
                        setState(() {
                          selectedColor = Color.fromRGBO(
                              redSliderValue.round(),
                              greenSliderValue.round(),
                              blueSliderValue.round(),
                              (opacitySliderValue / 100));
                        });
                      },
                      activeColor: widget.redSliderActiveColor,
                      inactiveColor: widget.redSliderInActiveColor,
                    ),
                  ),
                ],
              ),
              Row(
                children: <Widget>[
                  CircleAvatar(
                    radius: MediaQuery.of(context).size.width / 30,
                    backgroundColor: Colors.lightGreenAccent,
                  ),
                  SliderTheme(
                    data: SliderThemeData(
                      thumbColor: widget.greenSliderThumbColor,
                    ),
                    child: Slider(
                      min: 0,
                      max: 256,
                      value: greenSliderValue,
                      onChanged: (value) {
                        setState(() {
                          greenSliderValue = value;
                        });
                        setState(() {
                          selectedColor = Color.fromRGBO(
                              redSliderValue.round(),
                              greenSliderValue.round(),
                              blueSliderValue.round(),
                              (opacitySliderValue / 100));
                        });
                      },
                      activeColor: widget.greenSliderActiveColor,
                      inactiveColor: widget.greenSliderInActiveColor,
                    ),
                  ),
                ],
              ),
              Row(
                children: <Widget>[
                  CircleAvatar(
                    radius: MediaQuery.of(context).size.width / 30,
                    backgroundColor: Colors.lightBlueAccent,
                  ),
                  SliderTheme(
                    data: SliderThemeData(
                      thumbColor: widget.blueSliderThumbColor,
                    ),
                    child: Slider(
                      min: 0,
                      max: 256,
                      value: blueSliderValue,
                      onChanged: (value) {
                        setState(() {
                          blueSliderValue = value;
                        });
                        setState(() {
                          selectedColor = Color.fromRGBO(
                              redSliderValue.round(),
                              greenSliderValue.round(),
                              blueSliderValue.round(),
                              (opacitySliderValue / 100));
                        });
                      },
                      activeColor: widget.blueSliderActiveColor,
                      inactiveColor: widget.blueSliderInActiveColor,
                    ),
                  ),
                ],
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height / 30,
              ),
              Divider(
                thickness: 2,
              ),
              SizedBox(
                height: MediaQuery.of(context).size.width / 40,
              ),
              Row(
                children: <Widget>[
                  CircleAvatar(
                    radius: MediaQuery.of(context).size.width / 30,
                    backgroundColor: Colors.grey[300],
                  ),
                  SliderTheme(
                    data: widget.opacitySliderThemeData,
                    child: Slider(
                      value: opacitySliderValue,
                      min: 0,
                      max: 100,
                      onChanged: (val) {
                        setState(() {
                          opacitySliderValue = val;
                          selectedColor = Color.fromRGBO(
                              redSliderValue.round(),
                              greenSliderValue.round(),
                              blueSliderValue.round(),
                              (opacitySliderValue / 100));
                        });
                      },
                    ),
                  ),
                ],
              ),
            ],
          ),
        ),
        actions: <Widget>[
          FlatButton(
            textColor: widget.buttonTextColor,
            child: Text(
              'PICK',
            ),
            onPressed: () {
              setState(() {
                selectedColor = Color.fromRGBO(
                    redSliderValue.round(),
                    greenSliderValue.round(),
                    blueSliderValue.round(),
                    (opacitySliderValue / 100));
              });
              Navigator.of(context).pop(selectedColor);
            },
          ),
          FlatButton(
            textColor: widget.buttonTextColor,
            child: Text(
              'CANCEL',
            ),
            onPressed: () {
              Navigator.pop(context);
            },
          ),
        ],
      ),
    );
  }
}